package com.aucma.base.service;

import java.util.List;
import com.aucma.base.domain.RecordInStore;

/**
 * 入库记录Service接口
 * 
 * @author Yinq
 * @date 2023-09-21
 */
public interface IRecordInStoreService 
{
    /**
     * 查询入库记录
     * 
     * @param objId 入库记录主键
     * @return 入库记录
     */
    public RecordInStore selectRecordInStoreByObjId(Long objId);

    /**
     * 查询入库记录列表
     * 
     * @param recordInStore 入库记录
     * @return 入库记录集合
     */
    public List<RecordInStore> selectRecordInStoreList(RecordInStore recordInStore);

    /**
     * 新增入库记录
     * 
     * @param recordInStore 入库记录
     * @return 结果
     */
    public int insertRecordInStore(RecordInStore recordInStore);

    /**
     * 修改入库记录
     * 
     * @param recordInStore 入库记录
     * @return 结果
     */
    public int updateRecordInStore(RecordInStore recordInStore);

    /**
     * 批量删除入库记录
     * 
     * @param objIds 需要删除的入库记录主键集合
     * @return 结果
     */
    public int deleteRecordInStoreByObjIds(Long[] objIds);

    /**
     * 删除入库记录信息
     * 
     * @param objId 入库记录主键
     * @return 结果
     */
    public int deleteRecordInStoreByObjId(Long objId);
}
