package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.RecordInStore;
import com.aucma.base.service.IRecordInStoreService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 入库记录Controller
 *
 * @author Yinq
 * @date 2023-09-21
 */
@RestController
@RequestMapping("/base/inStore" )
public class RecordInStoreController extends BaseController {
    @Autowired
    private IRecordInStoreService recordInStoreService;

    /**
     * 查询入库记录列表
     */
    @PreAuthorize("@ss.hasPermi('base:inStore:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(RecordInStore recordInStore) {
        startPage();
        List<RecordInStore> list = recordInStoreService.selectRecordInStoreList(recordInStore);
        return getDataTable(list);
    }

    /**
     * 导出入库记录列表
     */
    @PreAuthorize("@ss.hasPermi('base:inStore:export')" )
    @Log(title = "入库记录" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, RecordInStore recordInStore) {
        List<RecordInStore> list = recordInStoreService.selectRecordInStoreList(recordInStore);
        ExcelUtil<RecordInStore> util = new ExcelUtil<RecordInStore>(RecordInStore. class);
        util.exportExcel(response, list, "入库记录数据" );
    }

    /**
     * 获取入库记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:inStore:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(recordInStoreService.selectRecordInStoreByObjId(objId));
    }

    /**
     * 新增入库记录
     */
    @PreAuthorize("@ss.hasPermi('base:inStore:add')" )
    @Log(title = "入库记录" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordInStore recordInStore) {
        recordInStore.setCreatedBy(getUsername());
        recordInStore.setCreatedTime(DateUtils.getNowDate());
        return toAjax(recordInStoreService.insertRecordInStore(recordInStore));
    }

    /**
     * 修改入库记录
     */
    @PreAuthorize("@ss.hasPermi('base:inStore:edit')" )
    @Log(title = "入库记录" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordInStore recordInStore) {
        recordInStore.setUpdatedBy(getUsername());
        recordInStore.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(recordInStoreService.updateRecordInStore(recordInStore));
    }

    /**
     * 删除入库记录
     */
    @PreAuthorize("@ss.hasPermi('base:inStore:remove')" )
    @Log(title = "入库记录" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordInStoreService.deleteRecordInStoreByObjIds(objIds));
    }
}
